#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-J1wwrBS5Mi43x3nkTmY3bn
key:                  tagstream-conduit-0.5.6-J1wwrBS5Mi43x3nkTmY3bn
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  63988b9bd873884c8b9dc4001e3f9993
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-J1wwrBS5Mi43x3nkTmY3bn
depends:
    attoparsec-0.14.4-XKrSjVngnD4c93iEpE5SP base-4.18.2.1
    blaze-builder-0.4.4.1-D2h3Qn3VgsyIHA3dmM49cD bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Io2qVGlYpC0Ko64AoDztcG
    conduit-1.3.6.1-EcgUgvtEMLyH8F5dS2Qay5
    conduit-extra-1.3.8-Pkl5t82V3lFiXu05t8a32
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    resourcet-1.2.6-Eiin09vl6BXE97MJ850Zwl text-2.0.2
    transformers-0.6.1.0 xml-conduit-1.9.1.4-SLc82Lkvor7Nazag80tdi

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

